@@ -11,7 +11,7 @@ use MARC::Convert::Wikidata::Item::Periodical;
 use MARC::Convert::Wikidata::Transform;
 use Scalar::Util qw(blessed);
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # Constructor.
 sub new {
@@ -44,6 +44,9 @@ sub new {
 	# MARC::Record object.
 	$self->{'marc_record'} = undef;
 
+	# Verbose mode.
+	$self->{'verbose'} = 0;
+
 	# Process parameters.
 	set_params($self, @params);
 
@@ -234,6 +237,14 @@ MARC::Record object.
 
 It's required.
 
+=item * C<verbose>
+
+Verbose mode.
+
+Could be 1 or 0.
+
+Default value is 0.
+
 =back
 
 Returns instance of object.
@@ -513,6 +524,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
